"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const co_body_1 = __importDefault(require("co-body"));
const response_1 = require("./response");
const helper_1 = require("./helper");
const request_1 = require("./request");
class Context {
    constructor(req, res, originalCtx) {
        this.req = req;
        this.res = res;
        this.originalCtx = originalCtx;
    }
    get credentials() {
        return this.originalCtx.credentials;
    }
    get service() {
        return this.originalCtx.service;
    }
    get query() {
        return this.req.query;
    }
    get requestId() {
        return this.originalCtx.requestId;
    }
    get accountId() {
        return this.originalCtx.accountId;
    }
    get function() {
        return this.originalCtx.function;
    }
    get region() {
        return this.originalCtx.region;
    }
    setHeader(field, value) {
        this.res.setHeader(field, value);
    }
    removeHeader(field) {
        this.res.removeHeader(field);
    }
    get header() {
        return this.res.header;
    }
    get headers() {
        return this.header;
    }
    get status() {
        return this.res.status;
    }
    set status(code) {
        this.res.status = code;
    }
    set body(value) {
        this.res.body = value;
    }
    get body() {
        return this.res.body;
    }
    finish() {
        return this.res.finish();
    }
    redirect(newUrl) {
        this.status = 301;
        this.setHeader("Location", newUrl);
    }
}
exports.Context = Context;
exports.createContext = (req, res, ctx) => __awaiter(this, void 0, void 0, function* () {
    const response = new response_1.Response(res);
    const request = new request_1.Request(req);
    const context = new Context(request, response, ctx);
    try {
        if (helper_1.couldHaveBody(req.method)) {
            context.req.body = yield co_body_1.default(req);
        }
    }
    catch (e) {
        console.error(e);
    }
    return context;
});
//# sourceMappingURL=context.js.map