"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mock_req_1 = __importDefault(require("mock-req"));
const AUTO_END_METHOD = ["GET", "HEAD", "DELETE"];
exports.couldHaveBody = (method) => AUTO_END_METHOD.indexOf(method) < 0;
exports.mockRequest = (req) => {
    req = req || {};
    const method = req.method || "GET";
    const body = req.body || {};
    const haveBody = exports.couldHaveBody(method);
    const request = new mock_req_1.default({
        method,
        url: "/",
        headers: Object.assign({}, (haveBody && {
            "Content-type": "application/json",
            "Content-Length": Buffer.byteLength(JSON.stringify(body), "utf8")
        }), req.headers)
    });
    if (haveBody) {
        request.write(body);
        request.end();
    }
    return Object.assign(request, {
        queries: req.query || {},
        clientIp: "127.0.0.1",
        path: "/"
    });
};
exports.mockResponse = () => {
    return {
        setStatusCode: (statusCode) => { },
        setHeader: (headerKey, headerValue) => { },
        deleteHeader: (headerKey) => { },
        send: (body) => { }
    };
};
exports.mockContext = () => {
    return {
        requestId: "b1c5100f-819d-c421-3a5e-7782a27d8a33",
        credentials: {
            accessKeyId: "STS.access_key_id",
            accessKeySecret: "access_key_secret",
            securityToken: "security_token"
        },
        function: {
            name: "my-func",
            handler: "index.handler",
            memory: 128,
            timeout: 10,
            initializer: "index.initializer",
            initializationTimeout: 10
        },
        service: {
            name: "my-service",
            logProject: "my-log-project",
            logStore: "my-log-store",
            qualifier: "qualifier",
            versionId: "1"
        },
        region: "cn-shanghai",
        accountId: "123456"
    };
};
//# sourceMappingURL=helper.js.map