"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const EMPTY_HTTP_STATUS_CODE = 204;
class Response {
    constructor(_res) {
        this._res = _res;
        this._headers = {};
        this._hasStatusSet = false;
    }
    get body() {
        return this._body;
    }
    set body(value) {
        if (value === null) {
            this.removeHeader("Content-Type");
            if (this.status !== EMPTY_HTTP_STATUS_CODE) {
                this.status = EMPTY_HTTP_STATUS_CODE;
            }
            return;
        }
        if (!this._hasStatusSet)
            this.status = 200;
        if ("string" == typeof value) {
            this.type = /^\s*</.test(value) ? "text/html" : "text/plain";
            this._body = value;
            return;
        }
        if (Buffer.isBuffer(value)) {
            this.type = "application/octet-stream";
            this._body = value.toString("base64");
            return;
        }
        this.type = "application/json";
        this._body = JSON.stringify(value);
    }
    get type() {
        return this._type;
    }
    set type(type) {
        this.setHeader("Content-Type", type);
    }
    get status() {
        return this._status;
    }
    set status(code) {
        this._status = code;
        if (code === EMPTY_HTTP_STATUS_CODE)
            this.body = null;
        this._hasStatusSet = true;
        this._res.setStatusCode(code);
    }
    get header() {
        return this._headers;
    }
    removeHeader(field) {
        delete this._headers[field];
        this._res.deleteHeader(field);
    }
    setHeader(field, val) {
        this._headers[field] = val;
        this._res.setHeader(field, val);
    }
    finish() {
        this._res.send(this._body || '');
    }
}
exports.Response = Response;
//# sourceMappingURL=response.js.map